/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.jxmap.layerlist;

import java.awt.Dialog;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import nl.cloudfarming.client.geoviewer.Layer;
import nl.cloudfarming.client.geoviewer.LayerAction;
import nl.cloudfarming.client.geoviewer.LayerInfo;
import org.openide.DialogDescriptor;
import org.openide.DialogDisplayer;
import org.openide.util.NbBundle;

/**
 * Action to open and close the settings panel for a layer.
 * 
 * @author Timon Veenstra
 */
@NbBundle.Messages({"settings_for_layer.name=Layer settings",
                    "settings_for_layer.dialog.title=Layer Settings",
                    "settings_for_layer.dialog.ok=Ok",
                    "settings_for_layer.dialog.cancel=Cancel"})
public class SettingsForLayerAction extends LayerAction {

    private LayerSettingsPanel panel;
    private Dialog dlg;
    private final LayerInfo layerInfo;
    private final Layer layer;

    public SettingsForLayerAction(LayerInfo layerInfo, Layer layer) {
        putValue(NAME, Bundle.settings_for_layer_name());
        this.layerInfo = layerInfo;
        this.layer = layer;
    }

    @Override
    public void actionPerformed(ActionEvent arg0) {

        panel = new LayerSettingsPanel(layer, layerInfo);
        DialogDescriptor dd = new DialogDescriptor(panel, Bundle.settings_for_layer_dialog_title());
        dd.setOptions(new Object[]{getOkButton(), getCancelButton()});
        dlg = DialogDisplayer.getDefault().createDialog(dd);
        dlg.setVisible(true);
    }

    private JButton getOkButton() {
        JButton jButtonOK = new JButton();
        jButtonOK.setText(Bundle.settings_for_layer_dialog_ok());
        jButtonOK.addActionListener(new ActionListener() {

            @Override
            public void actionPerformed(ActionEvent ae) {
//                LayerListTopComponent.findInstance().refresh();
                dlg.setVisible(false);
            }
        });
        return jButtonOK;
    }

    private JButton getCancelButton() {
        JButton jButtonCancel = new JButton();
        jButtonCancel.setText(Bundle.settings_for_layer_dialog_cancel());
        jButtonCancel.addActionListener(new ActionListener() {

            @Override
            public void actionPerformed(ActionEvent ae) {
                panel.cancelSettings();
//                LayerListTopComponent.findInstance().refresh();
                dlg.setVisible(false);
            }
        });
        return jButtonCancel;
    }
}
