/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.jxmap.layerlist;

import java.awt.event.ActionEvent;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import nl.cloudfarming.client.geoviewer.LayerAction;
import nl.cloudfarming.client.geoviewer.LayerInfo;
import org.openide.util.NbBundle;

/**
 * Action for toggling the visibility of a layer.
 * 
 * @author Timon Veenstra
 */
@NbBundle.Messages({"visibility layer hide=Hide",
                    "visibilityv layer show=Show"})
public class VisibilityLayerAction extends LayerAction {
    private final LayerInfo layerInfo;

    private static final long serialVersionUID = -1222090203615272257L;

    public VisibilityLayerAction(final LayerInfo layerInfo) {
        this.layerInfo = layerInfo;
        
        setName(layerInfo);

        layerInfo.addPropertyChangeListener(LayerInfo.PROPERTY_VISIBLE, new PropertyChangeListener() {

            @Override
            public void propertyChange(PropertyChangeEvent evt) {
                setName(layerInfo);
            }
        });
    }

    private void setName(LayerInfo layerInfo){
        if (layerInfo.isVisible()) {
            putValue(NAME, Bundle.visibility_layer_hide());
        } else {
            putValue(NAME, Bundle.visibilityv_layer_show());
        }
    }

    @Override
    public void actionPerformed(ActionEvent ae) {
        layerInfo.setVisible(!layerInfo.isVisible());
    }

    public LayerInfo getLayerInfo() {
        return layerInfo;
    }
    
    
}
